import java.net.*;
import java.io.*;

public class EasyHTTPGet {

  protected URL url;
  protected HttpURLConnection connection;
  protected String username;
  protected String password;
  protected int responseCode;

  public static void main(String[] args) throws Exception {
    EasyHTTPGet getter = new EasyHTTPGet(args[0]);
    System.out.println(getter.responseAsString());
  }

  public EasyHTTPGet(String url_) throws MalformedURLException, IOException {
    url = new URL(url_);
    if (url.getUserInfo() != null) {
      setCredentialsFromURL();
    }
    connect();
  }

  public EasyHTTPGet(URL url_) throws IOException {
    url = url_;
    if (url.getUserInfo() != null) {
      setCredentialsFromURL();
    }
    connect();
  }

  public EasyHTTPGet(String url_, String username_, String password_) 
    throws MalformedURLException, IOException
  {
    url = new URL(url_);
    username = username_;
    password = password_;
    connect();
  }

  public EasyHTTPGet(URL url_, String username_, String password_) 
    throws IOException
  {
    url = url_;
    username = username_;
    password = password_;
    connect();
  }

  protected void setCredentialsFromURL() {
    String[] cred = url.getUserInfo().split(":");
    username = cred[0];
    password = cred[1];
  }

  protected void connect() throws IOException {
    if (username != null && password != null) {
      Authenticator.setDefault(new Authenticator() {
        protected PasswordAuthentication getPasswordAuthentication() {
          return new PasswordAuthentication(username, password.toCharArray());
        }
      });
    }
    connection = (HttpURLConnection)url.openConnection();
  }

  public HttpURLConnection getConnection() {
    return connection;
  }

  public String responseAsString() {
    StringBuffer buff = new StringBuffer();
    try {
      InputStream urlStream = responseAsInputStream();
      BufferedReader in = new BufferedReader(new InputStreamReader(urlStream));
      String line;
      while ((line = in.readLine()) != null) {
        buff.append(line + "\n");
      }
      in.close();
      responseCode = connection.getResponseCode();
    }
    catch (IOException e) { /* do nothing, response will be empty */ }
    return buff.toString();
  }

  public InputStream responseAsInputStream() throws IOException {
    return connection.getInputStream();
  }

}

