import processing.pdf.*;

String[] data;
PFont font;

// angle of rotation between line segments (one direction for subject
// pronouns, one direction for object pronouns)
float theta = 0.08;

// difference between offsets in the text multiplied by this number to
// determine length of line segment
float lengthMultiplier = 0.004;

void setup() {
  size(6000, 6000, PDF, "output.pdf");
  smooth();
  data = loadStrings("data_kjv.txt");
  font = createFont("Arial", 7);
  noLoop();   
}

void draw() {
  
  background(255);
  translate(width/2, height/3);
  textFont(font);
  strokeWeight(5);
  
  stroke(128, 0, 128);
  noFill();
  ellipse(0, 0, 35, 35);
  
  // draw she/her
  stroke(255, 0, 0);
  fill(255, 0, 0);
  pushMatrix();
  plotPath(data, "she", "her");
  popMatrix();
  
  // draw he/him
  stroke(0, 0, 255);
  fill(0, 0, 255);
  pushMatrix();
  plotPath(data, "he", "him");
  popMatrix();
  
  endRecord();
  
}

// plotPath: draws a string of lines, adjusting direction and length
// according to the contents of the given array of strings
// expects each line to have the following format (tab-separated):
// offset  pronoun  context
// ... where offset is an integer, pronoun and context are strings
void plotPath(String[] data, String left, String right) {
  int lastOffset = 0;
  for (int i = 0; i < data.length; i++) {
    String[] vars = data[i].split("\t");
    int offset = int(vars[0]);
    String pronoun = vars[1];
    String context = vars[2];
    if (!pronoun.equals(left) && !pronoun.equals(right)) continue;
    if (pronoun.equals(left)) {
      rotate(theta);
    }
    else if (pronoun.equals(right)) {
      rotate(theta * -1);
    }
    float distance = (offset - lastOffset) * lengthMultiplier;
    if (i % 10 == 0) {
      text(context, 5, 0);
    }
    line(0, 0, 0, -distance);
    translate(0, -distance);
    lastOffset = offset;
  }
  ellipse(0, 0, 20, 20);
}
